searchData={"items":[{"type":"module","title":"ExCashfreeSDK","doc":"ExCashfreeSDK: Elixir SDK for Cashfree Payment Gateway\n\nThis SDK provides a convenient way to interact with Cashfree's Payment Gateway APIs\nin Elixir applications. It includes modules for various payment operations, refunds,\nand settlements.","ref":"ExCashfreeSDK.html"},{"type":"module","title":"Modules - ExCashfreeSDK","doc":"","ref":"ExCashfreeSDK.html#module-modules"},{"type":"module","title":"ExCashfreeSDK.PaymentGateway.Payments - ExCashfreeSDK","doc":"Handles payment-related operations:\n\n- `payment_for_order/1`: Fetch all payments for a specific order\n- `payment/2`: Get details of a specific payment\n- `order_pay/3`: Initiate a payment for an order\n- `submit_or_resend_otp/3`: Submit or resend OTP for payment authentication\n- `preauthorization/3`: Perform preauthorization actions (capture or void)","ref":"ExCashfreeSDK.html#module-excashfreesdk-paymentgateway-payments"},{"type":"module","title":"ExCashfreeSDK.PaymentGateway.Refunds - ExCashfreeSDK","doc":"Manages refund operations:\n\n- `create_refund/3`: Create a refund for an order\n- `get_refund/2`: Retrieve details of a specific refund\n- `get_refunds/1`: Fetch all refunds for an order","ref":"ExCashfreeSDK.html#module-excashfreesdk-paymentgateway-refunds"},{"type":"module","title":"ExCashfreeSDK.PaymentGateway.Settlements - ExCashfreeSDK","doc":"Handles settlement-related queries:\n\n- `get_settlements_for_order/1`: Retrieve settlement information for an order","ref":"ExCashfreeSDK.html#module-excashfreesdk-paymentgateway-settlements"},{"type":"module","title":"Usage - ExCashfreeSDK","doc":"To use this SDK, you need to configure your Cashfree API credentials. Add the following\nto your application's configuration:\n\n    config :ex_cashfree_sdk,\n      api_key: \"your_api_key\",\n      api_secret: \"your_api_secret\",\n      environment: :sandbox # or :production\n\nThen you can use the SDK functions in your application:\n\n    alias ExCashfreeSDK.PaymentGateway.Payments\n\n    # Fetch payment details\n    {:ok, payment_details} = Payments.payment(\"order_123\", \"payment_456\")","ref":"ExCashfreeSDK.html#module-usage"},{"type":"module","title":"Error Handling - ExCashfreeSDK","doc":"Most functions in this SDK return a tuple `{:ok, result}` for successful operations\nor `{:error, reason}` for failures. Always handle both cases in your application logic.","ref":"ExCashfreeSDK.html#module-error-handling"},{"type":"module","title":"Additional Resources - ExCashfreeSDK","doc":"- [Cashfree API Documentation](https://docs.cashfree.com/docs/)\n- [GitHub Repository](https://github.com/your-repo-link)\n\nFor more detailed information about each module and function, please refer to their\nrespective documentation.","ref":"ExCashfreeSDK.html#module-additional-resources"},{"type":"module","title":"ExCashfreeSDK.PaymentGateway","doc":"This module contains the APIs related to payment gateway","ref":"ExCashfreeSDK.PaymentGateway.html"},{"type":"function","title":"ExCashfreeSDK.PaymentGateway.create_order/1","doc":"Create order","ref":"ExCashfreeSDK.PaymentGateway.html#create_order/1"},{"type":"function","title":"Examples - ExCashfreeSDK.PaymentGateway.create_order/1","doc":"iex> order = %{\n      \"customer_details\" => %{\n        \"customer_id\" => \"7112AAA812234\",\n        \"customer_phone\" => \"9898989898\"\n      },\n      \"order_meta\" => %{\n        \"return_url\" => \"https://example.com/return\"\n      },\n      \"order_id\" => \"playstation_purchase_2\",\n      \"order_currency\" => \"INR\",\n      \"order_amount\" => 10.34\n    }\n    iex> ExCashfreeSDK.create_order(order)\n    {:ok,\n     %{\n       \"cart_details\" => nil,\n       \"cf_order_id\" => \"2183323902\",\n       \"created_at\" => \"2024-08-05T03:23:09+05:30\",\n       \"customer_details\" => %{\n         \"customer_email\" => nil,\n         \"customer_id\" => \"7112AAA812234\",\n         \"customer_name\" => nil,\n         \"customer_phone\" => \"9898989898\",\n         \"customer_uid\" => nil\n       },\n       \"entity\" => \"order\",\n       \"order_amount\" => 10.34,\n       \"order_currency\" => \"INR\",\n       \"order_expiry_time\" => \"2024-09-04T03:23:09+05:30\",\n       \"order_id\" => \"playstation_purchase_2\",\n       \"order_meta\" => %{\n         \"notify_url\" => nil,\n         \"payment_methods\" => nil,\n         \"return_url\" => \"https://example.com/return\"\n       },\n       \"order_note\" => nil,\n       \"order_splits\" => [],\n       \"order_status\" => \"ACTIVE\",\n       \"order_tags\" => nil,\n       \"payment_session_id\" => \"session_xyx\",\n       \"terminal_data\" => nil\n     }}","ref":"ExCashfreeSDK.PaymentGateway.html#create_order/1-examples"},{"type":"function","title":"ExCashfreeSDK.PaymentGateway.get_order/1","doc":"Get order","ref":"ExCashfreeSDK.PaymentGateway.html#get_order/1"},{"type":"function","title":"Examples - ExCashfreeSDK.PaymentGateway.get_order/1","doc":"iex> ExCashfreeSDK.get_order(\"2183323902\")\n    {:ok, %{\n      \"cart_details\" => nil,\n      \"cf_order_id\" => \"2183323902\",\n      \"created_at\" => \"2024-08-05T03:23:09+05:30\",\n      \"customer_details\" => %{\n        \"customer_email\" => nil,\n        \"customer_id\" => \"7112AAA812234\",\n        \"customer_name\" => nil,\n        \"customer_phone\" => \"9898989898\",\n        \"customer_uid\" => nil\n      },\n      \"entity\" => \"order\",\n      \"order_amount\" => 10.34,\n      \"order_currency\" => \"INR\",\n      \"order_expiry_time\" => \"2024-09-04T03:23:09+05:30\",\n      \"order_id\" => \"playstation_purchase_2\",\n      \"order_meta\" => %{\n        \"notify_url\" => nil,\n        \"payment_methods\" => nil,\n        \"return_url\" => \"https://example.com/return\"\n      },\n      \"order_note\" => nil,\n      \"order_splits\" => [],\n      \"order_status\" => \"ACTIVE\",\n      \"order_tags\" => nil,\n      \"payment_session_id\" => \"session_xyx\",\n      \"terminal_data\" => nil\n    }}","ref":"ExCashfreeSDK.PaymentGateway.html#get_order/1-examples"},{"type":"function","title":"ExCashfreeSDK.PaymentGateway.order_pay/3","doc":"Order pay","ref":"ExCashfreeSDK.PaymentGateway.html#order_pay/3"},{"type":"function","title":"Examples - ExCashfreeSDK.PaymentGateway.order_pay/3","doc":"iex> ExCashfreeSDK.order_pay(\"2183323902\", \"upi\", \"session_xyx\")\n    {:ok, %{\n      \"action\" => \"custom\",\n      \"cf_payment_id\" => \"5114911130273\",\n      \"channel\" => \"link\",\n      \"data\" => %{\n        \"url\" => nil,\n        \"payload\" => %{\n          \"bhim\" => \"https://payments-test.cashfree.com/pgbillpayuiapi/simulator/5114911130273?txnId=5114911130273&amount=1.00&pa=cashfree@testbank&pn=Cashfree&tr=5114911130273&am=1.00&cu=INR&mode=00&purpose=00&mc=5732&tn=Cashfree%20Simulator%20Payment\",\n          \"default\" => \"https://payments-test.cashfree.com/pgbillpayuiapi/simulator/5114911130273?txnId=5114911130273&amount=1.00&pa=cashfree@testbank&pn=Cashfree&tr=5114911130273&am=1.00&cu=INR&mode=00&purpose=00&mc=5732&tn=Cashfree%20Simulator%20Payment\",\n          \"gpay\" => \"https://payments-test.cashfree.com/pgbillpayuiapi/simulator/5114911130273?txnId=5114911130273&amount=1.00&pa=cashfree@testbank&pn=Cashfree&tr=5114911130273&am=1.00&cu=INR&mode=00&purpose=00&mc=5732&tn=Cashfree%20Simulator%20Payment\",\n          \"paytm\" => \"https://payments-test.cashfree.com/pgbillpayuiapi/simulator/5114911130273?txnId=5114911130273&amount=1.00&pa=cashfree@testbank&pn=Cashfree&tr=5114911130273&am=1.00&cu=INR&mode=00&purpose=00&mc=5732&tn=Cashfree%20Simulator%20Payment\",\n          \"phonepe\" => \"https://payments-test.cashfree.com/pgbillpayuiapi/simulator/5114911130273?txnId=5114911130273&amount=1.00&pa=cashfree@testbank&pn=Cashfree&tr=5114911130273&am=1.00&cu=INR&mode=00&purpose=00&mc=5732&tn=Cashfree%20Simulator%20Payment\",\n          \"web\" => \"https://sandbox.cashfree.com/pg/view/upi/4krk7c0l1.session_UY10UB1AAt1t9kv_7_3hyL7Fl0z0D0f3TH9yIuu29A2aNmCFr6zzOUF5DrVTYzomL3UqbmnmkrBQVHEE_pzK0JVJcmJNci29JdDI2rsk9mDy.39d601b7-ec26-486f-a663-87a7186cf6e7\"\n        },\n        \"content_type\" => nil,\n        \"method\" => nil\n      },\n      \"payment_amount\" => 1,\n      \"payment_method\" => \"upi\"\n    }}","ref":"ExCashfreeSDK.PaymentGateway.html#order_pay/3-examples"},{"type":"function","title":"ExCashfreeSDK.PaymentGateway.terminate_order/1","doc":"Terminate order","ref":"ExCashfreeSDK.PaymentGateway.html#terminate_order/1"},{"type":"function","title":"Examples - ExCashfreeSDK.PaymentGateway.terminate_order/1","doc":"iex> ExCashfreeSDK.terminate_order(\"2183323902\")\n    {:ok, %{\n      # Response structure\n    }}","ref":"ExCashfreeSDK.PaymentGateway.html#terminate_order/1-examples"},{"type":"module","title":"ExCashfreeSDK.PaymentGateway.Orders","doc":"Provides functions to interact with Cashfree's Payment Gateway Orders API.\n\nThis module allows you to create, retrieve, and terminate orders using Cashfree's Payment Gateway.","ref":"ExCashfreeSDK.PaymentGateway.Orders.html"},{"type":"module","title":"Examples - ExCashfreeSDK.PaymentGateway.Orders","doc":"alias ExCashfreeSDK.PaymentGateway.Orders\n\n    # Create an order\n    order_data = %{\n      customer_details: %{\n        customer_id: \"123456789\",\n        customer_phone: \"9908734801\",\n        customer_email: \"john@cashfree.com\",\n        customer_name: \"John Doe\"\n      },\n      order_id: \"xx-yy-zz-12345\",\n      order_amount: 111,\n      order_currency: \"INR\"\n    }\n\n    {:ok, created_order} = Orders.create_order(order_data)\n\n    # Get an order\n    {:ok, order} = Orders.get_order(\"xx-yy-zz-12345\")\n\n    # Terminate an order\n    {:ok, terminated_order} = Orders.terminate_order(\"xx-yy-zz-12345\")","ref":"ExCashfreeSDK.PaymentGateway.Orders.html#module-examples"},{"type":"function","title":"ExCashfreeSDK.PaymentGateway.Orders.create_order/1","doc":"Creates a new order using Cashfree's Payment Gateway.","ref":"ExCashfreeSDK.PaymentGateway.Orders.html#create_order/1"},{"type":"function","title":"Parameters - ExCashfreeSDK.PaymentGateway.Orders.create_order/1","doc":"* `order` - Map containing order details (see `t:order/0`)","ref":"ExCashfreeSDK.PaymentGateway.Orders.html#create_order/1-parameters"},{"type":"function","title":"Returns - ExCashfreeSDK.PaymentGateway.Orders.create_order/1","doc":"* `{:ok, response}` if the order was created successfully\n  * `{:error, reason}` if there was an error creating the order","ref":"ExCashfreeSDK.PaymentGateway.Orders.html#create_order/1-returns"},{"type":"function","title":"Example - ExCashfreeSDK.PaymentGateway.Orders.create_order/1","doc":"order_data = %{\n      customer_details: %{\n        customer_id: \"123456789\",\n        customer_phone: \"9908734801\",\n        customer_email: \"john@cashfree.com\",\n        customer_name: \"John Doe\"\n      },\n      order_id: \"xx-yy-zz-12345\",\n      order_amount: 111,\n      order_currency: \"INR\",\n      order_meta: %{\n        return_url: \"https://example.com/return\",\n        notify_url: \"https://example.com/notify\"\n      }\n    }\n\n    {:ok, created_order} = ExCashfreeSDK.PaymentGateway.Orders.create_order(order_data)","ref":"ExCashfreeSDK.PaymentGateway.Orders.html#create_order/1-example"},{"type":"function","title":"ExCashfreeSDK.PaymentGateway.Orders.get_order/1","doc":"Retrieves an existing order from Cashfree's Payment Gateway.","ref":"ExCashfreeSDK.PaymentGateway.Orders.html#get_order/1"},{"type":"function","title":"Parameters - ExCashfreeSDK.PaymentGateway.Orders.get_order/1","doc":"* `order_id` - String containing the unique identifier of the order","ref":"ExCashfreeSDK.PaymentGateway.Orders.html#get_order/1-parameters"},{"type":"function","title":"Returns - ExCashfreeSDK.PaymentGateway.Orders.get_order/1","doc":"* `{:ok, response}` if the order was retrieved successfully\n  * `{:error, reason}` if there was an error retrieving the order","ref":"ExCashfreeSDK.PaymentGateway.Orders.html#get_order/1-returns"},{"type":"function","title":"Example - ExCashfreeSDK.PaymentGateway.Orders.get_order/1","doc":"{:ok, order} = ExCashfreeSDK.PaymentGateway.Orders.get_order(\"xx-yy-zz-12345\")","ref":"ExCashfreeSDK.PaymentGateway.Orders.html#get_order/1-example"},{"type":"function","title":"ExCashfreeSDK.PaymentGateway.Orders.terminate_order/1","doc":"Terminates an existing order in Cashfree's Payment Gateway.","ref":"ExCashfreeSDK.PaymentGateway.Orders.html#terminate_order/1"},{"type":"function","title":"Parameters - ExCashfreeSDK.PaymentGateway.Orders.terminate_order/1","doc":"* `order_id` - String containing the unique identifier of the order to terminate","ref":"ExCashfreeSDK.PaymentGateway.Orders.html#terminate_order/1-parameters"},{"type":"function","title":"Returns - ExCashfreeSDK.PaymentGateway.Orders.terminate_order/1","doc":"* `{:ok, response}` if the order was terminated successfully\n  * `{:error, reason}` if there was an error terminating the order","ref":"ExCashfreeSDK.PaymentGateway.Orders.html#terminate_order/1-returns"},{"type":"function","title":"Example - ExCashfreeSDK.PaymentGateway.Orders.terminate_order/1","doc":"{:ok, terminated_order} = ExCashfreeSDK.PaymentGateway.Orders.terminate_order(\"xx-yy-zz-12345\")","ref":"ExCashfreeSDK.PaymentGateway.Orders.html#terminate_order/1-example"},{"type":"type","title":"ExCashfreeSDK.PaymentGateway.Orders.customer/0","doc":"Represents customer details for an order.","ref":"ExCashfreeSDK.PaymentGateway.Orders.html#t:customer/0"},{"type":"type","title":"Fields - ExCashfreeSDK.PaymentGateway.Orders.customer/0","doc":"* `:customer_id` - Unique identifier for the customer (required)\n  * `:customer_phone` - Customer's phone number (required)\n  * `:customer_email` - Customer's email address\n  * `:customer_name` - Customer's name\n  * `:customer_bank_account_number` - Customer's bank account number\n  * `:customer_bank_ifsc` - Customer's bank IFSC code\n  * `:customer_bank_code` - Customer's bank code","ref":"ExCashfreeSDK.PaymentGateway.Orders.html#t:customer/0-fields"},{"type":"type","title":"ExCashfreeSDK.PaymentGateway.Orders.order/0","doc":"Represents an order to be created or retrieved.","ref":"ExCashfreeSDK.PaymentGateway.Orders.html#t:order/0"},{"type":"type","title":"Fields - ExCashfreeSDK.PaymentGateway.Orders.order/0","doc":"* `:customer_details` - Customer information (see `t:customer/0`)\n  * `:order_id` - Unique identifier for the order\n  * `:order_amount` - Amount of the order\n  * `:order_currency` - Currency of the order (e.g., \"INR\")\n  * `:order_meta` - Additional metadata for the order","ref":"ExCashfreeSDK.PaymentGateway.Orders.html#t:order/0-fields"},{"type":"module","title":"ExCashfreeSdk.PaymentGateway.PaymentLinks","doc":"Payment Links APIs implementation for Cashfree SDK","ref":"ExCashfreeSdk.PaymentGateway.PaymentLinks.html"},{"type":"module","title":"ExCashfreeSdk.PaymentGateway.Refunds","doc":"Refunds APIs implementation for Cashfree SDK.\n\nThis module provides functions to create and retrieve refunds for orders\nprocessed through Cashfree's Payment Gateway.","ref":"ExCashfreeSdk.PaymentGateway.Refunds.html"},{"type":"function","title":"ExCashfreeSdk.PaymentGateway.Refunds.create_refund/3","doc":"Creates a refund for a specific order.","ref":"ExCashfreeSdk.PaymentGateway.Refunds.html#create_refund/3"},{"type":"function","title":"Parameters - ExCashfreeSdk.PaymentGateway.Refunds.create_refund/3","doc":"* `order_id` - The ID of the order to be refunded.\n  * `refund_params` - A map containing refund details (see `t:refund/0`).\n  * `refund_splits` - Optional list of refund splits (default: []).","ref":"ExCashfreeSdk.PaymentGateway.Refunds.html#create_refund/3-parameters"},{"type":"function","title":"Examples - ExCashfreeSdk.PaymentGateway.Refunds.create_refund/3","doc":"iex> refund_params = %{\n    ...>   refund_amount: 100.00,\n    ...>   refund_id: \"refund_123\",\n    ...>   refund_note: \"Customer requested refund\",\n    ...>   refund_speed: \"STANDARD\"\n    ...> }\n    iex> ExCashfreeSdk.PaymentGateway.Refunds.create_refund(\"order_123\", refund_params)\n    {:ok, %{refund_id: \"refund_123\", order_id: \"order_123\", status: \"PENDING\"}}","ref":"ExCashfreeSdk.PaymentGateway.Refunds.html#create_refund/3-examples"},{"type":"function","title":"ExCashfreeSdk.PaymentGateway.Refunds.get_refund/2","doc":"Retrieves details of a specific refund for an order.","ref":"ExCashfreeSdk.PaymentGateway.Refunds.html#get_refund/2"},{"type":"function","title":"Parameters - ExCashfreeSdk.PaymentGateway.Refunds.get_refund/2","doc":"* `order_id` - The ID of the order.\n  * `refund_id` - The ID of the refund to retrieve.","ref":"ExCashfreeSdk.PaymentGateway.Refunds.html#get_refund/2-parameters"},{"type":"function","title":"Examples - ExCashfreeSdk.PaymentGateway.Refunds.get_refund/2","doc":"iex> ExCashfreeSdk.PaymentGateway.Refunds.get_refund(\"order_123\", \"refund_123\")\n    {:ok, %{\n      refund_id: \"refund_123\",\n      order_id: \"order_123\",\n      status: \"PROCESSED\",\n      amount: 100.00,\n      created_at: \"2023-04-01T12:00:00Z\"\n    }}","ref":"ExCashfreeSdk.PaymentGateway.Refunds.html#get_refund/2-examples"},{"type":"function","title":"ExCashfreeSdk.PaymentGateway.Refunds.get_refunds/1","doc":"Retrieves all refunds for a specific order.","ref":"ExCashfreeSdk.PaymentGateway.Refunds.html#get_refunds/1"},{"type":"function","title":"Parameters - ExCashfreeSdk.PaymentGateway.Refunds.get_refunds/1","doc":"* `order_id` - The ID of the order to fetch refunds for.","ref":"ExCashfreeSdk.PaymentGateway.Refunds.html#get_refunds/1-parameters"},{"type":"function","title":"Examples - ExCashfreeSdk.PaymentGateway.Refunds.get_refunds/1","doc":"iex> ExCashfreeSdk.PaymentGateway.Refunds.get_refunds(\"order_123\")\n    {:ok, [\n      %{refund_id: \"refund_123\", status: \"PROCESSED\", amount: 50.00},\n      %{refund_id: \"refund_124\", status: \"PENDING\", amount: 25.00}\n    ]}","ref":"ExCashfreeSdk.PaymentGateway.Refunds.html#get_refunds/1-examples"},{"type":"type","title":"ExCashfreeSdk.PaymentGateway.Refunds.refund/0","doc":"","ref":"ExCashfreeSdk.PaymentGateway.Refunds.html#t:refund/0"},{"type":"module","title":"ExCashfreeSdk.PaymentGateway.Settlements","doc":"Settlements APIs implementation for Cashfree SDK.\n\nThis module provides functions to retrieve settlement information\nfor orders processed through Cashfree's Payment Gateway.","ref":"ExCashfreeSdk.PaymentGateway.Settlements.html"},{"type":"function","title":"ExCashfreeSdk.PaymentGateway.Settlements.get_settlements_for_order/1","doc":"Retrieves settlement information for a specific order.","ref":"ExCashfreeSdk.PaymentGateway.Settlements.html#get_settlements_for_order/1"},{"type":"function","title":"Parameters - ExCashfreeSdk.PaymentGateway.Settlements.get_settlements_for_order/1","doc":"* `order_id` - The ID of the order to fetch settlements for.","ref":"ExCashfreeSdk.PaymentGateway.Settlements.html#get_settlements_for_order/1-parameters"},{"type":"function","title":"Returns - ExCashfreeSdk.PaymentGateway.Settlements.get_settlements_for_order/1","doc":"* `{:ok, settlements}` - A list of settlement details for the order.\n  * `{:error, reason}` - If there was an error fetching the settlements.","ref":"ExCashfreeSdk.PaymentGateway.Settlements.html#get_settlements_for_order/1-returns"},{"type":"function","title":"Examples - ExCashfreeSdk.PaymentGateway.Settlements.get_settlements_for_order/1","doc":"iex> ExCashfreeSdk.PaymentGateway.Settlements.get_settlements_for_order(\"order_123\")\n    {:ok, [\n      %{\n        settlement_id: \"settlement_001\",\n        order_id: \"order_123\",\n        amount: 1000.00,\n        status: \"PROCESSED\",\n        settled_at: \"2023-04-01T12:00:00Z\"\n      },\n      %{\n        settlement_id: \"settlement_002\",\n        order_id: \"order_123\",\n        amount: 500.00,\n        status: \"PENDING\",\n        settled_at: nil\n      }\n    ]}","ref":"ExCashfreeSdk.PaymentGateway.Settlements.html#get_settlements_for_order/1-examples"},{"type":"module","title":"ExCashfreeSDK.PaymentGateway.Payments","doc":"Payments APIs implementation for Cashfree SDK","ref":"ExCashfreeSDK.PaymentGateway.Payments.html"},{"type":"function","title":"ExCashfreeSDK.PaymentGateway.Payments.order_pay/3","doc":"","ref":"ExCashfreeSDK.PaymentGateway.Payments.html#order_pay/3"},{"type":"function","title":"ExCashfreeSDK.PaymentGateway.Payments.payment/2","doc":"","ref":"ExCashfreeSDK.PaymentGateway.Payments.html#payment/2"},{"type":"function","title":"ExCashfreeSDK.PaymentGateway.Payments.payment_for_order/1","doc":"","ref":"ExCashfreeSDK.PaymentGateway.Payments.html#payment_for_order/1"},{"type":"function","title":"ExCashfreeSDK.PaymentGateway.Payments.preauthorization/3","doc":"","ref":"ExCashfreeSDK.PaymentGateway.Payments.html#preauthorization/3"},{"type":"function","title":"ExCashfreeSDK.PaymentGateway.Payments.submit_or_resend_otp/3","doc":"If you accept OTP on your own page, you can use the below API to send OTP to Cashfree.","ref":"ExCashfreeSDK.PaymentGateway.Payments.html#submit_or_resend_otp/3"},{"type":"function","title":"Examples - ExCashfreeSDK.PaymentGateway.Payments.submit_or_resend_otp/3","doc":"iex> ExCashfreeSDK.PaymentGateway.submit_or_resend_otp(\"cf_payment_id\", :SUBMIT_OTP, \"123456\")\n    {:ok, %{}}","ref":"ExCashfreeSDK.PaymentGateway.Payments.html#submit_or_resend_otp/3-examples"},{"type":"type","title":"ExCashfreeSDK.PaymentGateway.Payments.otp_action/0","doc":"","ref":"ExCashfreeSDK.PaymentGateway.Payments.html#t:otp_action/0"},{"type":"type","title":"ExCashfreeSDK.PaymentGateway.Payments.preauth_action/0","doc":"","ref":"ExCashfreeSDK.PaymentGateway.Payments.html#t:preauth_action/0"},{"type":"module","title":"ExCashfreeSDK.HTTPClient.ReqClient","doc":"This module is the HTTP client for Req","ref":"ExCashfreeSDK.HTTPClient.ReqClient.html"},{"type":"function","title":"ExCashfreeSDK.HTTPClient.ReqClient.delete/3","doc":"","ref":"ExCashfreeSDK.HTTPClient.ReqClient.html#delete/3"},{"type":"function","title":"ExCashfreeSDK.HTTPClient.ReqClient.get/3","doc":"","ref":"ExCashfreeSDK.HTTPClient.ReqClient.html#get/3"},{"type":"function","title":"ExCashfreeSDK.HTTPClient.ReqClient.get_param/2","doc":"","ref":"ExCashfreeSDK.HTTPClient.ReqClient.html#get_param/2"},{"type":"function","title":"ExCashfreeSDK.HTTPClient.ReqClient.patch/3","doc":"","ref":"ExCashfreeSDK.HTTPClient.ReqClient.html#patch/3"},{"type":"function","title":"ExCashfreeSDK.HTTPClient.ReqClient.post/3","doc":"","ref":"ExCashfreeSDK.HTTPClient.ReqClient.html#post/3"},{"type":"function","title":"ExCashfreeSDK.HTTPClient.ReqClient.put/3","doc":"","ref":"ExCashfreeSDK.HTTPClient.ReqClient.html#put/3"},{"type":"extras","title":"ExCashfreeSDK","doc":"# ExCashfreeSDK\n\nExCashfreeSDK is an Elixir library for interacting with the Cashfree payment gateway API.\n\nhttps://docs.cashfree.com/reference","ref":"readme.html"},{"type":"extras","title":"Installation - ExCashfreeSDK","doc":"Add `ex_cashfree_sdk` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_cashfree_sdk, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - ExCashfreeSDK","doc":"ExCashfreeSDK uses the sandbox environment by default. To configure the base URL for API requests, you can set it in your application's configuration.\n\nFor sandbox environment (default):\nNo additional configuration is needed. The SDK will use https://sandbox.cashfree.com as the base URL.\n\nFor production environment:\nAdd the following to your config/config.exs (or the appropriate environment-specific config file):\n\n```elixir\nconfig :ex_cashfree_sdk, base_url: \"https://api.cashfree.com\"\n```","ref":"readme.html#configuration"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2024 Yatender Singh Suman\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}